<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>FontsDialog</name>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="28"/>
        <source>LabelsFont</source>
        <translation>Etiquetas</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="31"/>
        <location filename="../../src/FontsDialog.cpp" line="51"/>
        <source>ResetDefaultValue</source>
        <translation>Reajustar</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="48"/>
        <source>FieldsFont</source>
        <translation>Campos</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="63"/>
        <source>LanguageFontOverrides</source>
        <translation>Surdefiniciónes de tipos de letra</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="73"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="75"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="89"/>
        <source>Fonts Settings</source>
        <translation>Tipos de letra</translation>
    </message>
</context>
<context>
    <name>HelpBrowser</name>
    <message>
        <location filename="../../src/HelpBrowser.cpp" line="8"/>
        <source>Home</source>
        <translation>Casa</translation>
    </message>
    <message>
        <location filename="../../src/HelpBrowser.cpp" line="9"/>
        <source>Back</source>
        <translation>Volver</translation>
    </message>
    <message>
        <location filename="../../src/HelpBrowser.cpp" line="30"/>
        <source>Help: %1</source>
        <translation>Ayuda: %1</translation>
    </message>
</context>
<context>
    <name>KeyboardAcceleratorsDialog</name>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="23"/>
        <source>Action</source>
        <translation>Acción</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="23"/>
        <source>Key</source>
        <translation>Tecla</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="43"/>
        <source>Clear key</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="44"/>
        <source>Set key</source>
        <translation>Definir</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="45"/>
        <source>Reset key</source>
        <translation>Reajustar</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="63"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="65"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="87"/>
        <source>Keyboard Accelerator Definitions</source>
        <translation>Aceleradores de Teclado</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="122"/>
        <source>&lt;press key&gt;</source>
        <translation>&lt;Entre una teclea&gt;</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="190"/>
        <source>Duplicate key binding</source>
        <translation>Definición doble</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="191"/>
        <source>Key &apos;</source>
        <translation>Tecle &apos;</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="191"/>
        <source>&apos;
is currently assigned to
&apos;</source>
        <translation>&apos; es actualmente usado por &apos;</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="192"/>
        <source>&apos;.
Overwrite the current assignment?</source>
        <translation>&apos;. No obstante, asignar la teclea?</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../src/MainWindow.cpp" line="60"/>
        <location filename="../../src/MainWindow.cpp" line="176"/>
        <location filename="../../src/MainWindow.cpp" line="217"/>
        <source>StartQuiz</source>
        <translation>Empezar un testo</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="62"/>
        <location filename="../../src/MainWindow.cpp" line="218"/>
        <source>ManageGlossaries</source>
        <translation>Administrar los glosarios</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="64"/>
        <location filename="../../src/MainWindow.cpp" line="219"/>
        <source>Import...</source>
        <translation>Importar...</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="66"/>
        <location filename="../../src/MainWindow.cpp" line="220"/>
        <source>Export...</source>
        <translation>Exportar...</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="70"/>
        <location filename="../../src/MainWindow.cpp" line="222"/>
        <source>Preferences...</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="72"/>
        <location filename="../../src/MainWindow.cpp" line="223"/>
        <source>Quit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="132"/>
        <location filename="../../src/MainWindow.cpp" line="236"/>
        <source>About...</source>
        <translation>Acerca de toMOTko</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="176"/>
        <source>RestartQuiz</source>
        <translation>Recomenzar el testo</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="275"/>
        <source>AboutToMOTko...</source>
        <translation>Acerca de toMOTko...</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="275"/>
        <source>AboutMessage</source>
        <translation>&lt;html&gt;&lt;h2&gt;toMOTko v0.11.2&lt;/h2&gt;&lt;p&gt;Pequeña aplicación para aprender nuevo vocabulario.&lt;/p&gt;&lt;p&gt;Escrito por Frederic Bergeron&lt;br/&gt;(&lt;a href=&quot;mailto:fbergeron@users.sourceforge.net&quot;&gt;fbergeron@users.sourceforge.net&lt;/a&gt;)&lt;br/&gt;Copyright (c) 2006-2010&lt;/p&gt;&lt;p&gt;toMOTko es software libre GPL v2.&lt;/p&gt;&lt;p&gt;Homepage: &lt;a href=&quot;http://tomotko.sourceforge.net&quot;&gt;http://tomotko.sourceforge.net&lt;/a&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="68"/>
        <location filename="../../src/MainWindow.cpp" line="221"/>
        <source>ShowAllGlossariesAndTerms</source>
        <translation>Mostrar todos los glosarios y palabras</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="52"/>
        <location filename="../../src/MainWindow.cpp" line="213"/>
        <source>Reveal</source>
        <translation>Revelar</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="54"/>
        <location filename="../../src/MainWindow.cpp" line="214"/>
        <source>RightAnswer</source>
        <translation>Respuesta correcta</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="56"/>
        <location filename="../../src/MainWindow.cpp" line="215"/>
        <source>WrongAnswer</source>
        <translation>Respuesta incorrecta</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="58"/>
        <location filename="../../src/MainWindow.cpp" line="216"/>
        <source>EditQuizTerm</source>
        <translation>Editar una palabra del quiz</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="74"/>
        <location filename="../../src/MainWindow.cpp" line="224"/>
        <source>AddFolder</source>
        <translation>Añadir una carpeta</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="76"/>
        <location filename="../../src/MainWindow.cpp" line="225"/>
        <source>AddGlossary</source>
        <translation>Añadir un glosario</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="78"/>
        <location filename="../../src/MainWindow.cpp" line="226"/>
        <source>RemoveItem</source>
        <translation>Borrar un tema</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="80"/>
        <location filename="../../src/MainWindow.cpp" line="227"/>
        <source>AddTerm</source>
        <translation>Añadir una palabra</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="82"/>
        <location filename="../../src/MainWindow.cpp" line="228"/>
        <source>EditTerm</source>
        <translation>Editar una palabra</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="84"/>
        <location filename="../../src/MainWindow.cpp" line="229"/>
        <source>RemoveTerm</source>
        <translation>Borrar una palabra</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="86"/>
        <location filename="../../src/MainWindow.cpp" line="230"/>
        <source>CheckAllTerms</source>
        <translation>Seleccionar todas las palabras</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="88"/>
        <location filename="../../src/MainWindow.cpp" line="231"/>
        <source>InverseCheckedTerms</source>
        <translation>Invertir la selección</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="90"/>
        <location filename="../../src/MainWindow.cpp" line="232"/>
        <source>Maximize</source>
        <translation>Ampliar</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="298"/>
        <source>ConfirmResumeQuiz</source>
        <translation>Usted ya he empezado un quiz en los idiomas selectionados.  Quiere continuar este quiz?</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="304"/>
        <source>Yes</source>
        <translation>Si</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="305"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="317"/>
        <source>NoTermsMarkedForStudy</source>
        <translation>No hay palabras selectionadas. El testo no puede empezar. Usa el Administrador de glosarios para seleccionar palabras a estudiar.</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="322"/>
        <source>TermsMissing</source>
        <translation>Imposible de encuentrar las palabras del quiz.  El quiz no puede empezar.</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="92"/>
        <location filename="../../src/MainWindow.cpp" line="233"/>
        <source>Search...</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="130"/>
        <location filename="../../src/MainWindow.cpp" line="235"/>
        <source>Help...</source>
        <translation>Ayuda</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="134"/>
        <source>Keyboard Accelerator Definitions</source>
        <translation>Aceleradores de Teclado...</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="34"/>
        <source>Length</source>
        <translation>Duración de los
quizes (repeticiones)</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="54"/>
        <source>QuizLengthShortest</source>
        <translation>Corto (1)</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="55"/>
        <source>QuizLengthMedium</source>
        <translation>Regular (3)</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="57"/>
        <source>QuizLengthLongest</source>
        <translation>Largo (5)</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="73"/>
        <source>DigraphesEnabled</source>
        <translation>Digrafos activados</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="87"/>
        <source>InterfaceLanguage</source>
        <translation>Idioma de la interfaz</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="143"/>
        <source>Revealing Sequences Settings</source>
        <translation>Secuencias de revelación...</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="189"/>
        <source>Preferences...</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="76"/>
        <source>hideQuizButtons</source>
        <translation>Ocultar Botones del Quiz</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="79"/>
        <source>ShowAltInTermList</source>
        <translation>Mostrar la pronunciación</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="137"/>
        <source>Study Language Definitions</source>
        <translation>Idiomas estudiados...</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="140"/>
        <source>Fonts Settings</source>
        <translation>Tipos de letra...</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="151"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="153"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>PropertiesPanel</name>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="59"/>
        <location filename="../../src/PropertiesPanel.cpp" line="92"/>
        <source>Words</source>
        <translation>Palabras</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="99"/>
        <source>Glossaries</source>
        <translation>Glosarios</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="106"/>
        <source>Folders</source>
        <translation>Carpetas</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="127"/>
        <location filename="../../src/PropertiesPanel.cpp" line="284"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="133"/>
        <location filename="../../src/PropertiesPanel.cpp" line="279"/>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="137"/>
        <location filename="../../src/PropertiesPanel.cpp" line="280"/>
        <source>Content</source>
        <translation>Contenido</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="144"/>
        <location filename="../../src/PropertiesPanel.cpp" line="282"/>
        <source>Items</source>
        <translation>Temas</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="144"/>
        <location filename="../../src/PropertiesPanel.cpp" line="282"/>
        <source>Selected</source>
        <translation>Quiz</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="144"/>
        <location filename="../../src/PropertiesPanel.cpp" line="282"/>
        <source>Checked</source>
        <translation>Marcados</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="144"/>
        <location filename="../../src/PropertiesPanel.cpp" line="282"/>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="169"/>
        <location filename="../../src/PropertiesPanel.cpp" line="285"/>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="175"/>
        <location filename="../../src/PropertiesPanel.cpp" line="286"/>
        <source>CreationDate</source>
        <translation>Creación</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="181"/>
        <location filename="../../src/PropertiesPanel.cpp" line="287"/>
        <source>ModificationDate</source>
        <translation>Modificación</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>en</source>
        <translation>Inglés</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>fr</source>
        <translation>Francés</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>es</source>
        <translation>Español</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>ja</source>
        <translation>Japonés</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>de</source>
        <translation>Alemán</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>ar</source>
        <translation>Árabe</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>bg</source>
        <translation>Búlgaro</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>el</source>
        <translation>Griego</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>cs</source>
        <translation>Checo</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>da</source>
        <translation>Danés</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>it</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>eo</source>
        <translation>Esperanto</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>fi</source>
        <translation>Finés</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>he</source>
        <translation>Hebreo</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>hi</source>
        <translation>Hindi</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>hu</source>
        <translation>Húngaro</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>ko</source>
        <translation>Coreano</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>nl</source>
        <translation>Deutch</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>pt</source>
        <translation>Portugués</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>la</source>
        <translation>Latín</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>no</source>
        <translation>Noruego</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>rm</source>
        <translation>Romanche</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>ru</source>
        <translation>Ruso</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>sw</source>
        <translation>Swahili</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>th</source>
        <translation>Tailandés</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>ro</source>
        <translation>Rumano</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>sv</source>
        <translation>Sueco</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="9"/>
        <source>vi</source>
        <translation>Vietnamita</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="9"/>
        <source>zh</source>
        <translation>Chino</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="9"/>
        <source>tl</source>
        <translation>Tagalo</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="40"/>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="39"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="41"/>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
    <message>
        <location filename="../../src/ResultListItem.cpp" line="20"/>
        <location filename="../../src/ResultListItem.cpp" line="33"/>
        <location filename="../../src/TermListItem.cpp" line="23"/>
        <location filename="../../src/TermListItem.cpp" line="36"/>
        <source>Undefined</source>
        <translation>Indefinido</translation>
    </message>
    <message>
        <location filename="../../src/FolderParser.cpp" line="46"/>
        <location filename="../../src/MainWindow.cpp" line="270"/>
        <location filename="../../src/TermDialog.cpp" line="246"/>
        <location filename="../../src/VocabParser.cpp" line="85"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="270"/>
        <source>ErrorSavingData</source>
        <translation>Un error ocurió escribiendo los data.  Averigüe las permisionnes de los archivos y el espacio libre del disco.</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="288"/>
        <location filename="../../src/SequenceDialog.cpp" line="200"/>
        <location filename="../../src/SequenceDialog.cpp" line="206"/>
        <location filename="../../src/SequencesDialog.cpp" line="85"/>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="87"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="833"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="967"/>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="298"/>
        <location filename="../../src/MainWindow.cpp" line="317"/>
        <location filename="../../src/MainWindow.cpp" line="322"/>
        <location filename="../../src/QuizFrame.cpp" line="387"/>
        <location filename="../../src/QuizFrame.cpp" line="757"/>
        <location filename="../../src/QuizFrame.cpp" line="763"/>
        <source>Information</source>
        <translation>Información</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="408"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="458"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="484"/>
        <source>OperationSuccessful</source>
        <translation>Operación completada con éxito</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="416"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="419"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="460"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="486"/>
        <source>OperationFailed</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../../src/Controller.cpp" line="737"/>
        <source>MyGlossaries</source>
        <translation>Mis glosarios</translation>
    </message>
    <message>
        <location filename="../../src/FolderParser.cpp" line="47"/>
        <location filename="../../src/VocabParser.cpp" line="86"/>
        <source>ParseError</source>
        <translation>Error de parsing a la linea %1, col. %2. %3.</translation>
    </message>
    <message>
        <location filename="../../src/Controller.cpp" line="144"/>
        <source>NewFolder</source>
        <translation>Nueva carpeta</translation>
    </message>
    <message>
        <location filename="../../src/Controller.cpp" line="173"/>
        <source>NewGlossary</source>
        <translation>Nuevo glosario</translation>
    </message>
</context>
<context>
    <name>QuizFrame</name>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="99"/>
        <location filename="../../src/QuizFrame.cpp" line="128"/>
        <location filename="../../src/QuizFrame.cpp" line="635"/>
        <location filename="../../src/QuizFrame.cpp" line="638"/>
        <source>Word/Expr.</source>
        <translation>Palabra/Expr.</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="104"/>
        <location filename="../../src/QuizFrame.cpp" line="139"/>
        <location filename="../../src/QuizFrame.cpp" line="149"/>
        <location filename="../../src/QuizFrame.cpp" line="187"/>
        <location filename="../../src/QuizFrame.cpp" line="202"/>
        <location filename="../../src/QuizFrame.cpp" line="636"/>
        <location filename="../../src/QuizFrame.cpp" line="639"/>
        <location filename="../../src/QuizFrame.cpp" line="640"/>
        <location filename="../../src/QuizFrame.cpp" line="643"/>
        <source>???</source>
        <translation>???</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="126"/>
        <location filename="../../src/QuizFrame.cpp" line="637"/>
        <source>Alt./Phon.</source>
        <translation>Pronunciación</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="169"/>
        <location filename="../../src/QuizFrame.cpp" line="642"/>
        <source>Examples/Comments</source>
        <translation>Ejemplos/Comentarios</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="387"/>
        <source>WellDone</source>
        <translation>Felicitationes! Usted ha aprendido todas las %1 palabras seleccionadaѕ.  Para estudiar otras palabras, usa el Administrador de glosarios y selecciona otras palabras.</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="757"/>
        <location filename="../../src/QuizFrame.cpp" line="763"/>
        <source>DissociatedWord</source>
        <translation>Esta palabra ha cambiado de su glosario original.  No es posible de editarlo.</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="197"/>
        <location filename="../../src/QuizFrame.cpp" line="641"/>
        <source>Image</source>
        <translation>Imagen</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="47"/>
        <location filename="../../src/SearchDialog.cpp" line="169"/>
        <source>Results</source>
        <translation>Resultados</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="61"/>
        <location filename="../../src/SearchDialog.cpp" line="174"/>
        <source>Glossary</source>
        <translation>Glosario</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="61"/>
        <location filename="../../src/SearchDialog.cpp" line="174"/>
        <source>Location</source>
        <translation>Camino</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="72"/>
        <location filename="../../src/SearchDialog.cpp" line="176"/>
        <source>View Glossary</source>
        <translation>Ir al glosario</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="113"/>
        <location filename="../../src/SearchDialog.cpp" line="187"/>
        <source>Search...</source>
        <translation>Buscar...</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="77"/>
        <location filename="../../src/SearchDialog.cpp" line="178"/>
        <source>Edit Term</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="82"/>
        <location filename="../../src/SearchDialog.cpp" line="180"/>
        <source>Remove Term(s)</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="88"/>
        <location filename="../../src/SearchDialog.cpp" line="182"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="170"/>
        <location filename="../../src/SearchDialog.cpp" line="208"/>
        <source>%1 term(s) found</source>
        <translation>%1 palabra(s) encontradas</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="288"/>
        <source>ConfirmRemoveSelectedTerms</source>
        <translation>Usted está seguro de borrar la(s) palabra(s) seleccionada(s)?</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="294"/>
        <source>Yes</source>
        <translation>Si</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="295"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="336"/>
        <source>MultipleTranslationsDetectedForRemoveTermsCaption</source>
        <translation>Borrar palabras</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="336"/>
        <source>MultipleTranslationsDetectedForRemoveTerms</source>
        <translation>Algunas palabras seleccionadas tienen traducciones en varios idiomas.  Seleccione los traducciones que usted quisiere borrar.</translation>
    </message>
</context>
<context>
    <name>SequenceDialog</name>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="22"/>
        <source>Quiz</source>
        <translation>Ventana de Testo</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="52"/>
        <source>FirstLanguage</source>
        <translation>Idioma natal</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="56"/>
        <location filename="../../src/SequenceDialog.cpp" line="88"/>
        <source>Word/Expr.</source>
        <translation>Palabra/Expr.</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="72"/>
        <source>TestLanguage</source>
        <translation>Idioma estudiado</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="86"/>
        <source>Alt./Phon.</source>
        <translation>Pronunciación</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="102"/>
        <source>Image</source>
        <translation>Imagen</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="115"/>
        <source>CommentLabelPanel</source>
        <translation>Ejemplos/Comentarios</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="128"/>
        <source>Sequence</source>
        <translation>Secuencia</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="191"/>
        <source>AddRevealingSequence</source>
        <translation>Añadir una secuencia de revelación...</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="200"/>
        <source>SequenceIsEmpty</source>
        <translation>La secuencia está vacía. Si Usted quiere cancelarla clique Cancelar para cerrar la ventana.</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="206"/>
        <source>SequenceNotTerminated</source>
        <translation>La sequencia no es valida. Se termina por un operator de unión.  Debe añadir un otro item o borrar el ultimo operator.</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="166"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="168"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>SequencesDialog</name>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="23"/>
        <source>Existing Sequences</source>
        <translation>Secuencias existentes</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="47"/>
        <source>QuizWindow</source>
        <translation>Ventana de Testo</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="62"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="64"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="78"/>
        <source>RevealingOrders</source>
        <translation>Secuencias de revelación</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="85"/>
        <source>RevealingOrderMandatory</source>
        <translation>Usted debe seleccionar por lo menos una secuencia de revelación.  Usted debe definir una nueva secuencia si no hay una disponible.</translation>
    </message>
</context>
<context>
    <name>StudyLanguagesDialog</name>
    <message>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="26"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="28"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="45"/>
        <source>Study Language Definitions</source>
        <translation>Idiomas estudiados</translation>
    </message>
    <message>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="87"/>
        <source>StudyLanguagesMandatory</source>
        <translation>Usted debe seleccionar por lo menos dos idiomas
(un para su idioma natal y un otro para su idioma a estudiar.</translation>
    </message>
</context>
<context>
    <name>TermDialog</name>
    <message>
        <location filename="../../src/TermDialog.cpp" line="62"/>
        <location filename="../../src/TermDialog.cpp" line="84"/>
        <source>Word/Expr.</source>
        <translation>Palabra/Expr.</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="82"/>
        <source>Alt./Phon.</source>
        <translation>Pronunciación</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="109"/>
        <source>Examples/Comments</source>
        <translation>Ejemplos/Comentarios</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="167"/>
        <source>EditTerm</source>
        <translation>Editar una palabra</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="137"/>
        <source>Image</source>
        <translation>Imagen</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="128"/>
        <source>setImage</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="132"/>
        <source>clearImage</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="214"/>
        <source>SetImage...</source>
        <translation>Afectar</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="148"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="150"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="214"/>
        <source>Images (*.png *.gif)</source>
        <translation>Imagenes (*.png *.gif)</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="246"/>
        <source>CannotReadImage</source>
        <translation>No puede leer esta imagen.</translation>
    </message>
</context>
<context>
    <name>TranslationSelectionDialog</name>
    <message>
        <location filename="../../src/TranslationSelectionDialog.cpp" line="15"/>
        <source>Languages</source>
        <translation>Idiomas</translation>
    </message>
    <message>
        <location filename="../../src/TranslationSelectionDialog.cpp" line="37"/>
        <source>CheckAllLanguages</source>
        <translation>Seleccionar todos los idiomas</translation>
    </message>
    <message>
        <location filename="../../src/TranslationSelectionDialog.cpp" line="45"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/TranslationSelectionDialog.cpp" line="47"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>Util</name>
    <message>
        <location filename="../../src/Util.cpp" line="22"/>
        <source>VerySmall</source>
        <translation>Muy pequeño</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="23"/>
        <source>Small</source>
        <translation>Pequeño</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="24"/>
        <source>Medium</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="25"/>
        <source>Large</source>
        <translation>Grande</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="26"/>
        <source>VeryLarge</source>
        <translation>Muy grande</translation>
    </message>
</context>
<context>
    <name>VocabularyManagerFrame</name>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="1015"/>
        <source>MultipleTranslationsDetectedForRemoveTermsCaption</source>
        <translation>Borrar palabras</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="1015"/>
        <source>MultipleTranslationsDetectedForRemoveTerms</source>
        <translation>Algunas palabras seleccionadas tienen traducciones en varios idiomas.  Seleccione los traducciones que usted quisiere borrar.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="361"/>
        <source>MultipleTranslationsDetectedForImport</source>
        <translation>El glosario contiene palabras en varios idiomas.  Seleccione las traducciones a importar.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="442"/>
        <source>MultipleTranslationsDetectedForExport</source>
        <translation>El glosario contiene palabras en varios idiomas.  Seleccione las traducciones a exportar.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="46"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="596"/>
        <source>Glossaries</source>
        <translation>Glosarios</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="458"/>
        <source>GlossaryExportSuccessful</source>
        <translation>El glosario ha ido exportado con éxito.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="416"/>
        <source>ItemImportFailed</source>
        <translation>Un error ocurió. Los data no han ido importados.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="419"/>
        <source>ItemImportFailedZipFileExpected</source>
        <translation>Typo de archivo invalid. Debe ser un archivo .zip. Los data no han ido importados con éxito.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="460"/>
        <source>GlossaryExportFailed</source>
        <translation>Un error ocurió. El glosario no ha ido exportado.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="833"/>
        <source>ConfirmRemoveItem</source>
        <translation>Usted está seguro de borrar este item?</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="839"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="973"/>
        <source>Yes</source>
        <translation>Si</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="840"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="974"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="967"/>
        <source>ConfirmRemoveSelectedTerms</source>
        <translation>Usted está seguro de borrar la(s) palabra(s) seleccionada(s)?</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="186"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="604"/>
        <source>Properties</source>
        <translation>Propiedades</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="187"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="605"/>
        <source>Words</source>
        <translation>Palabras</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="468"/>
        <source>MultipleTranslationsDetectedForFolderExport</source>
        <translation>La carpeta contiene palabras en varios idiomas.  Seleccione las traducciones a exportar.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="484"/>
        <source>FolderExportSuccessful</source>
        <translation>La carpeta ha ido exportado con éxito.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="486"/>
        <source>FolderExportFailed</source>
        <translation>Un error ocurió. La carpeta no ha ido exportado.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="353"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="361"/>
        <source>Import...</source>
        <translation>Importar Datos</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="405"/>
        <source>ImportSuccessful</source>
        <translation>Los data han ido importados con éxito.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="407"/>
        <source>InvisibleImport</source>
        <translation>

Los datos nuevos no son visibles por el momento.  Para verlos, Usted necesita seleccionar otros idiomas en los selectores de idiomas.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="442"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="453"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="468"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="479"/>
        <source>Export...</source>
        <translation>Exportar Datos</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="353"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="454"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="480"/>
        <source>Glossaries (*.zip)</source>
        <translation>Glosarios (*.zip)</translation>
    </message>
</context>
</TS>
